==> haskell-wai-middleware-static-0.9.3-181-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-middleware-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-middleware-static
version:              0.9.3
visibility:           public
id:                   wai-middleware-static-0.9.3-IUiZ7uvnU2lDdKxRQir4FN
key:                  wai-middleware-static-0.9.3-IUiZ7uvnU2lDdKxRQir4FN
license:              BSD-3-Clause
copyright:            (c) 2012-2014 Andrew Farmer
maintainer:           Andrew Farmer <afarmer@ittc.ku.edu>
author:               Andrew Farmer <afarmer@ittc.ku.edu>
stability:            experimental
homepage:             https://github.com/scotty-web/wai-middleware-static
synopsis:             WAI middleware that serves requests to static files.
description:
    WAI middleware that intercepts requests to static files and serves them
    if they exist.

    [WAI] <http://hackage.haskell.org/package/wai>

category:             Web
abi:                  33af1a7fc161f440e7119c37aae6cc03
exposed:              True
exposed-modules:      Network.Wai.Middleware.Static
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-middleware-static-0.9.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-middleware-static-0.9.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-middleware-static-0.9.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-middleware-static
hs-libraries:         HSwai-middleware-static-0.9.3-IUiZ7uvnU2lDdKxRQir4FN
depends:
    base-4.18.2.1 base16-bytestring-1.0.2.0-Dwd5n4mSUH32rjuqPFOreR
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-BjsOb6FJgTCBp7n5ZEroI4 directory-1.3.8.5
    expiring-cache-map-0.0.6.1-9nbCjzEjUhp3RX0zgYKSEm
    filepath-1.4.300.1 http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS
    mime-types-0.1.2.0-2lnuHjhOzQ4DFNhuFJ9ART
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC text-2.0.2 time-1.12.2
    wai-3.2.4-DrO6v22Rmno6pXUhKStSuj

haddock-interfaces:
    /usr/share/doc/haskell-wai-middleware-static/html/wai-middleware-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-middleware-static/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-middleware-static-0.9.3-183-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-middleware-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-middleware-static
version:              0.9.3
visibility:           public
id:                   wai-middleware-static-0.9.3-ED9WMXd7moF38yCRAwE2sx
key:                  wai-middleware-static-0.9.3-ED9WMXd7moF38yCRAwE2sx
license:              BSD-3-Clause
copyright:            (c) 2012-2014 Andrew Farmer
maintainer:           Andrew Farmer <afarmer@ittc.ku.edu>
author:               Andrew Farmer <afarmer@ittc.ku.edu>
stability:            experimental
homepage:             https://github.com/scotty-web/wai-middleware-static
synopsis:             WAI middleware that serves requests to static files.
description:
    WAI middleware that intercepts requests to static files and serves them
    if they exist.

    [WAI] <http://hackage.haskell.org/package/wai>

category:             Web
abi:                  5658efae2ad36371d135d324b645109b
exposed:              True
exposed-modules:      Network.Wai.Middleware.Static
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-middleware-static-0.9.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-middleware-static-0.9.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-middleware-static-0.9.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-middleware-static
hs-libraries:         HSwai-middleware-static-0.9.3-ED9WMXd7moF38yCRAwE2sx
depends:
    base-4.18.2.1 base16-bytestring-1.0.2.0-ARBAmNNbyxLEDoUwDjra0R
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-I0vIPZWrlt0Gys06a7iUtx directory-1.3.8.5
    expiring-cache-map-0.0.6.1-KG8rYsKjKdlKBHp3mHN3H6
    filepath-1.4.300.1 http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    mime-types-0.1.2.0-2lnuHjhOzQ4DFNhuFJ9ART
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC text-2.0.2 time-1.12.2
    wai-3.2.4-DggAE0S6Fb43aX3BIvUJ63

haddock-interfaces:
    /usr/share/doc/haskell-wai-middleware-static/html/wai-middleware-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-middleware-static/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
